@@ -22,6 +22,23 @@ plt.rcParams.update({'font.family': 'STIXGeneral', 'mathtext.fontset': 'stix'})
 ####***************************     1.1 Supplier Selection       ****************************###
 
 def load_supplier():
+    """ Supplier data
+    
+
+    Yields:
+    -------
+    supplier : a pandas DataFrame object that contains 100 samples with the columns of 
+        'Warranty Terms', 'Payment Terms', 'Technical Support',
+       'Sustainability Efforts', 'Finp.nancial Stability', 'Unit Cost',
+       'Lead Time (Days)' and 'On Time Delivery'
+
+    Use :
+        For evaluation model practice
+
+    Reference:
+        https://github.com/LinBaiTao/Supplier_Selection_Methods 
+
+    """
     data = np.array([[ 2.42,  2.8 ,  8.25,  3.09,  8.21,  1.05,  8.  ,  0.75],
        [ 6.51,  1.88,  3.6 ,  6.45,  4.31,  1.21, 13.  ,  0.83],
        [ 8.51,  1.06,  2.97,  9.36,  5.06,  1.22, 12.  ,  0.91],
@@ -140,6 +157,25 @@ def load_supplier():
 ####***************************     1.2 Roller Cosater       ****************************###
 
 def load_roller20():
+    """ Roller coaster data
+    
+
+    Yields:
+    -------
+    Roller : a pandas DataFrame object that contains 20 samples with the columns of 
+        'Name', 'Park', 'City/Region', 'City/State/Region', 'Country/Region',
+       'Geographic Region', 'Construction', 'Type', 'Status',
+       'Year/Date Opened', 'Height (feet)', ' Speed (mph)', 'Length (feet)',
+       'Inversions (YES or NO)', 'Number of Inversions', 'Drop (feet)',
+       'Duration (min:sec)', 'G Force', 'Vertical Angle (degrees)'
+
+    Use :
+        For evaluation model practice
+
+    Reference:
+        https://www.comap.com/highschool/contests/himcm/COMAP_RollerCoasterData_2018.xlsx
+
+    """
     data = np.array([['10 Inversion Roller Coaster', 'Chimelong Paradise', 'Panyu',
         'Guangzhou, Guangdong', 'China', 'Asia', 'Steel', 'Sit Down',
         'Operating', 2006, 98.4, 45.0, 2788.8, 'YES', 10, np.nan,
@@ -222,10 +258,51 @@ def load_roller20():
     roller = pd.DataFrame(data=data,index = index,columns = feature_names)
     return roller
 
+def fetch_roller():
+    """ Roller coaster data(download data from 
+    https://www.comap.com/highschool/contests/himcm/COMAP_RollerCoasterData_2018.xlsx)
+    
+
+    Yields:
+    -------
+    roller_all : a pandas DataFrame object that contains 48 samples with the columns of 
+        'Name', 'Park', 'City/Region', 'City/State/Region', 'Country/Region',
+       'Geographic Region', 'Construction', 'Type', 'Status',
+       'Year/Date Opened', 'Height (feet)', ' Speed (mph)', 'Length (feet)',
+       'Inversions (YES or NO)', 'Number of Inversions', 'Drop (feet)',
+       'Duration (min:sec)', 'G Force', 'Vertical Angle (degrees)'
+
+    Use :
+        For evaluation model practice
+
+    Reference:
+        https://www.comap.com/highschool/contests/himcm/COMAP_RollerCoasterData_2018.xlsx
+
+    """    
+    url = 'https://www.comap.com/highschool/contests/himcm/COMAP_RollerCoasterData_2018.xlsx'
+    roller_all = pd.read_excel(url)
+    return roller_all
+
 
 ####***************************     1.3 Aircraft       ****************************###
 
 def load_aircraft():
+    """ Aircraft data
+    
+
+    Yields:
+    -------
+    aircraft : a pandas DataFrame object that contains 5 samples with the columns of 
+        '最大速度(马赫)', '飞行范围(km)', '最大负载(磅)', '费用(美元)', '可靠性', '灵敏性'
+
+    Use :
+        For evaluation model practice
+
+    Reference:
+        Python数学实验与建模/司守奎,孙玺菁
+
+    """
+
     data = np.array([[2.0e+00, 1.5e+03, 2.0e+04, 5.5e+06, 5.0e-01, 1.0e+00],
        [2.5e+00, 2.7e+03, 1.8e+04, 6.5e+06, 3.0e-01, 5.0e-01],
        [1.8e+00, 2.0e+03, 2.1e+04, 4.5e+06, 7.0e-01, 7.0e-01],
@@ -239,6 +316,21 @@ def load_aircraft():
 ####***************************     1.4 Hospital       ****************************###
 
 def load_hospital():
+    """ Hospital data
+    
+
+    Yields:
+    -------
+    Roller : a pandas DataFrame object that contains 11 samples with the columns of 
+        'X1','X2',...,'X9'
+
+    Use :
+        For evaluation model practice
+
+    Reference:
+        Unkown
+
+    """
     data = np.array([[100,90,100,84,90,100,100,100,100],
     [100,100,78.6,100,90,100,100,100,100],
     [75,100,85.7,100,90,100,100,100,100],
@@ -252,12 +344,31 @@ def load_hospital():
     [100,100 ,92.9 , 100, 90 , 100, 100 ,100 ,100]])
 
     index = list('ABCDEFGHIJK')
-    columns = range(1,10)
+    columns = ['X'+str(i) for i in range(1,10)]
     hospital= pd.DataFrame(data=data,index=index,columns=columns)
     return hospital
 
 ####***************************     1.5 Battery       ****************************###
 def load_battery():
+    """ Battery data
+    
+
+    Yields:
+    -------
+    battery : a pandas DataFrame object that contains 80 samples with the columns of 
+        'Price(USD)', 'Weight(pounds)', 'Power Rating Capability(kWh)',
+       'steady', 'peak', 'Length(inch)', 'Width(inch)', 'Height(inch)',
+       'Depth of Discharge(DoD)%', 'Circles of Life Time',
+       'Round Trip Efficiency(RET)%', 'Warranty(year)', 'Low Temperature',
+       'High Temperature', 'Battery Type'
+
+    Use :
+        For evaluation model practice
+
+    Reference:
+        The author(Wang Haihua) collected data from the Internet
+
+    """
     data = np.array([[10000.0, 297.0, 14.0, 5.0, 5.0, 20.8, 15.7, 41.0, 90.0, 6000,
         97.0, 15.0, 0.0, 50.0, 'LFP'],
        [13000.0, 297.0, 13.0, 2.0, 3.3, 20.8, 15.7, 41.0, 90.0, 6000,
@@ -305,7 +416,7 @@ def load_battery():
        [10000.0, 287.0, 9.0, 3.4, 10.0, 22.0, 10.0, 68.0, 84.0, 6200,
         96.5, 10.0, -10.0, 45.0, 'Lithium-ion'],
        [7400.0, 318.036129032258, 6.3, 3.870769230769231, 6.85, 22.44,
-        32.7, 17.7, 80.0, 6200, 96.0, 10.0, 10.0, 30.0, nan],
+        32.7, 17.7, 80.0, 6200, 96.0, 10.0, 10.0, 30.0, np.nan],
        [13000.0, 346.0, 10.0, 5.0, 7.6, 27.5, 50.0, 9.0,
         89.9423076923077, 6200, 96.6, 10.0, 0.0, 50.0, 'LiFePO4'],
        [15000.0, 346.0, 15.0, 3.870769230769231, 6.85, 33.05793103448276,
@@ -321,7 +432,7 @@ def load_battery():
        [11320.88235294118, 318.036129032258, 17.28, 5.0, 10.0,
         33.05793103448276, 21.21137931034483, 34.07965517241379,
         89.9423076923077, 6200, 91.17241379310343, 10.0, -4.24, 36.72,
-        nan],
+        np.nan],
        [11320.88235294118, 318.036129032258, 9.799714285714288,
         3.870769230769231, 6.85, 33.05793103448276, 21.21137931034483,
         34.07965517241379, 89.9423076923077, 6200, 91.17241379310343,
@@ -332,7 +443,7 @@ def load_battery():
         89.9423076923077, 3000, 100.0, 10.0, -4.24, 36.72, 'LiFePO4'],
        [2000.0, 30.0, 1.2, 1.5, 3.0, 33.05793103448276,
         21.21137931034483, 34.07965517241379, 100.0, 2000, 100.0, 7.0,
-        -30.0, 55.0, nan],
+        -30.0, 55.0, np.nan],
        [20000.0, 218.0, 6.8, 3.870769230769231, 6.85, 16.57, 25.0, 191.0,
         80.0, 6600, 95.0, 5.0, 0.0, 50.0, 'Lithium-ion'],
        [7700.0, 360.0, 13.5, 3.870769230769231, 6.85, 23.6, 9.84, 70.0,
@@ -357,6 +468,21 @@ def load_battery():
 ####***************************     2.1 Portfolio       ****************************###
 
 def load_portfolio():
+    """ Portfolio data
+    
+
+    Yields:
+    -------
+    portfolio : a pandas DataFrame object that contains 4 samples with the columns of 
+       'r(%)','q(%)','p(%)','u(RMB)'
+
+    Use :
+        For optimization model practice
+
+    Reference:
+        Python数学实验与建模/司守奎,孙玺菁
+
+    """
     data = np.array([[28,2.5,1,103],[21,1.5,2,198],[23,5.5,4.5,52],[25,2.6,6.5,40]])
     index = ['s'+str(i) for i in range(1,5)]
     columns = ['r(%)','q(%)','p(%)','u(RMB)']
@@ -366,6 +492,21 @@ def load_portfolio():
 ####***************************     2.2 Ambulance       ****************************###
 
 def load_ambulance():
+    """ Ambulance data
+    
+
+    Yields:
+    -------
+    ambulance : a pandas DataFrame object that contains 80 samples with the columns of 
+       1,2,3,4,5,6
+
+    Use :
+        For optimization model practice
+
+    Reference:
+        https://www.comap.com/highschool/contests/himcm/2013problems.html
+
+    """
     data = np.array([[1,1,0,0,0,0],
                     [1,1,1,0,0,0],
                     [0,0,1,0,1,1],
@@ -377,8 +518,22 @@ def load_ambulance():
     ambulance = pd.DataFrame(data=data,index=index,columns=columns)
     return ambulance
 
-####***************************     2.3 Ambulance       ****************************###
+####***************************     2.3 Oil       *************************************###
 def load_oil():
+    """ Oil data 
+
+    Yields:
+    -------
+    oil : a pandas DataFrame object that contains 5 samples with the columns of 
+       '价格','硬度'
+
+    Use :
+        For optimization model practice
+
+    Reference:
+        Python数学实验与建模/司守奎,孙玺菁
+
+    """
     data = np.array([[110, 120, 130, 110, 115],[8.8,6.1,2.0,4.2,5.0]])
     index = ['价格','硬度']
     columns = ['VEG1','VEG2','OIL1','OIL2','OIL3']
@@ -387,6 +542,21 @@ def load_oil():
 
 ####***************************     2.4 Factory(clothes) ****************************###
 def load_factory_clothes():
+    """ factory data 
+
+    Yields:
+    -------
+    factory_clothes : a pandas DataFrame object that contains 3 samples with the columns of 
+       '设备租金(元)', '材料成本(元/件)', '销售价格(元/件)', '人工工时(小时/件)', '设备工时(小时/件)',
+       '设备可用工时'
+
+    Use :
+        For optimization model practice
+
+    Reference:
+        Unknown
+
+    """
     data = np.array([[5000, 280, 400, 5, 3.0, 300],[2000, 30, 40, 1, 0.5, 300],
        [2000, 200, 300, 4, 2.0, 300]])
     index = list('ABC')
@@ -396,7 +566,21 @@ def load_factory_clothes():
     return factory_clothes
 
 ####***************************     2.3 Swim           ****************************###
-def swim():
+def load_swim():
+    """ Relay swimming data 
+
+    Yields:
+    -------
+    swim : a pandas DataFrame object that contains 3 samples with the columns of 
+       '泳姿1', '泳姿2', '泳姿3', '泳姿4'
+
+    Use :
+        For optimization model practice
+
+    Reference:
+        Unknown
+
+    """
     data = np.array([[ 56, 74, 61, 63],
        [63, 69, 65, 71],
        [57, 77, 63, 67],
@@ -408,6 +592,22 @@ def swim():
 
 ####***************************     2.4 Plants           ****************************###
 def load_plant():
+    """ Plant data 
+
+    Yields:
+    -------
+    plant : a pandas DataFrame object that contains 48 samples with the columns of 
+       'Name', 'comp_rate', 'MinAgeRequirement', 'MinDiplomaRequirement',
+       'MinExperienceRequirementYear', 'PhysicalorIntellectual', 'WeeklyHour',
+       'WeeklyWageRate', 'Type', 'Experience', 'Remote'
+
+    Use :
+        For optimization model practice
+
+    Reference:
+        https://www.comap.com/highschool/contests/himcm/HiMCM2020ProblemB_ThreatenedPlantsData.xlsx
+
+    """
     data = np.array([['1-Flowering Plants-502', 0.66, 0.67, 0.6, 11616.17065,
         6053.241613, 5993.308527, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
         0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
@@ -503,6 +703,20 @@ def load_plant():
 ####***************************     3.1 Shanghai Confirms(from March 1)       ****************************###
 
 def load_shanghaicases():
+    """ Epidemic data in Shanghai(2022)
+
+    Yields:
+    -------
+    shanghai : a pandas DataFrame object that contains 41 samples with the columns of 
+       '新增确诊', '新增无症状', '无症状者转归', '隔离管控确诊', '隔离管控无症状'
+
+    Use :
+        For change model practice
+
+    Reference:
+        The official account "Shanghai Release"
+
+    """    
     data = np.array([[1.0000e+00, 1.0000e+00,        np.nan,        np.nan, 1.0000e+00],
        [3.0000e+00, 5.0000e+00,        np.nan,        np.nan, 5.0000e+00],
        [2.0000e+00, 1.4000e+01,        np.nan,        np.nan, 1.4000e+01],
@@ -552,6 +766,20 @@ def load_shanghaicases():
 
 ####***************************     3.2 Population      ****************************###
 def load_population():
+    """ Population data of U.S.(1970-2010)
+
+    Yields:
+    -------
+    df : a pandas DataFrame object that contains 22 samples with the columns of 
+      '年份','人口'
+
+    Use :
+        For change model practice
+
+    Reference:
+        Unknown
+
+    """ 
     df = pd.DataFrame()
     df["年份"] = [i for i in  range(1790,2010,10)]
     df["人口"] = [3.9,5.3,7.2,9.6,12.9,17.1,23.2,31.4,38.6,50.2,62.9,76,92,106.5,123.2,131.7,150.7,179.3,204,226.5,251.4,281.4]
@@ -564,6 +792,20 @@ def load_population():
 
 ####***************************     4.1 Restaurant     ****************************###
 def load_restaurant():
+    """ restaurant sales data
+
+    Yields:
+    -------
+    restaurant : a pandas DataFrame object that contains 37 samples with the columns of 
+       'day','sales'
+
+    Use :
+        For prediction model practice
+
+    Reference:
+        Unknown
+
+    """ 
     data = np.array([
        [   1, 3023],
        [   2, 3039],
@@ -610,6 +852,22 @@ def load_restaurant():
 
 ####***************************     4.2 Titanic     ****************************###
 def load_titanic():
+    """ Titanic data
+
+    Yields:
+    -------
+    titanic : a pandas DataFrame object that contains 80 samples with the columns of 
+       'Name', 'comp_rate', 'MinAgeRequirement', 'MinDiplomaRequirement',
+       'MinExperienceRequirementYear', 'PhysicalorIntellectual', 'WeeklyHour',
+       'WeeklyWageRate', 'Type', 'Experience', 'Remote''新增确诊', '新增无症状', '无症状者转归', '隔离管控确诊', '隔离管控无症状'
+
+    Use :
+        For change model practice
+
+    Reference:
+        Kaggle
+
+    """ 
     data = np.array([[1, 0, 3, 'Braund, Mr. Owen Harris', 'male', 22.0, 1, 0,
         'A/5 21171', 7.25, np.nan, 'S'],
        [2, 1, 1, 'Cumings, Mrs. John Bradley (Florence Briggs Thayer)',
@@ -779,15 +1037,49 @@ def load_titanic():
     titanic = pd.DataFrame(data=data,columns=columns)
     return titanic
 
+def fetch_mead():
+    """ Lake Mead's monthly elevation data
+
+    Yields:
+    -------
+    mead : a pandas DataFrame object that contains  samples with the columns of 
+       'Name', 'comp_rate', 'MinAgeRequirement', 'MinDiplomaRequirement',
+       'MinExperienceRequirementYear', 'PhysicalorIntellectual', 'WeeklyHour',
+       'WeeklyWageRate', 'Type', 'Experience', 'Remote''新增确诊', '新增无症状', '无症状者转归', '隔离管控确诊', '隔离管控无症状'
+
+    Use :
+        For change model practice
+
+    Reference:
+        https://www.comap.com/highschool/contests/himcm/2021_Problems/2021_HiMCM_LakeMead_MonthlyElevationData.xlsx
+
+    """ 
+    url = 'https://www.comap.com/highschool/contests/himcm/2021_Problems/2021_HiMCM_LakeMead_MonthlyElevationData.xlsx'
+    mead = pd.read_excel(url)
+    return mead
 
 
 ###########################################################################################
 ###############################     5 Explaination        ###############################
 ###########################################################################################
 
-####***************************     35.1 Adult_us       ****************************###
+####***************************     5.1 Adult_us       ****************************###
 
 def load_adult():
+    """ Adult data
+
+    Yields:
+    -------
+    adult : a pandas DataFrame object that contains 80 samples with the columns of 
+       'sex', 'age', 'educ', 'hours', 'income_more_50K''Name'
+
+    Use :
+        For explaination model practice
+
+    Reference:
+        Unknown
+
+    """ 
     data = np.array([[' Male', 39, 13, 40, 0],
        [' Male', 50, 13, 13, 0],
        [' Male', 38, 9, 40, 0],
@@ -890,4 +1182,25 @@ def load_adult():
        [' Male', 32, 9, 40, 0]])
     columns = ['sex', 'age', 'educ', 'hours', 'income_more_50K']
     adult = pd.DataFrame(data=data,columns=columns)
-    return adult
\ No newline at end of file
+    return adult
+
+####***************************     5.2 Trialon       ****************************###
+def fetch_trialon():
+    """ Trialon data
+
+    Yields:
+    -------
+    adult : a pandas DataFrame object that contains 3217 samples with the columns of 
+       'BIB NO.', 'AGE', 'GENDER', 'CATEGORY', 'SWIM', 'T1', 'BIKE', 'T2',
+       'RUN', 'FINALTM'
+
+    Use :
+        For explaination model practice
+
+    Reference:
+        https://www.comap.com/highschool/contests/himcm/2016_Files/HiMCM_TriDataSet.xlsx
+
+    """ 
+    url = 'https://www.comap.com/highschool/contests/himcm/2016_Files/HiMCM_TriDataSet.xlsx'
+    trialon = pd.read_excel(url)
+    return trialon
\ No newline at end of file
